##  Step 5: Create a Webhook for Survey Responses
Create a PUSH webhook for the POLL_RESULT_UPDATED event. In the Target URL field, enter the function URL. For instructions, see [Creating a Webhook](https://help.sap.com/docs/leanix/ea/webhooks?locale=en-US&state=PRODUCTION&version=CLOUD#loio275e18367a441014869bb7aa3562039e__creating_a_webhook).
